@@ -18,6 +18,7 @@ import org.eclipse.core.resources.IProject;
 import org.eclipse.core.runtime.IAdaptable;
 import org.eclipse.egit.core.project.RepositoryMapping;
 import org.eclipse.egit.ui.Activator;
+import org.eclipse.egit.ui.internal.CommonUtils;
 import org.eclipse.egit.ui.internal.SWTUtils;
 import org.eclipse.egit.ui.internal.UIIcons;
 import org.eclipse.egit.ui.internal.UIText;
@@ -50,7 +51,7 @@ import org.eclipse.ui.services.IServiceLocator;
 public class SwitchToMenu extends ContributionItem implements
 		IWorkbenchContribution {
 	/** the maximum number of branches to show in the sub-menu */
-	private static final int MAX_NUM_MENU_ENTRIES = 20;
+	static final int MAX_NUM_MENU_ENTRIES = 20;
 
 	private ISelectionService srv;
 
@@ -132,12 +133,13 @@ public class SwitchToMenu extends ContributionItem implements
 				}
 			}
 		});
-		new MenuItem(menu, SWT.SEPARATOR);
+		createSeparator(menu);
 		try {
 			String currentBranch = repository.getFullBranch();
 			Map<String, Ref> localBranches = repository.getRefDatabase().getRefs(
 					Constants.R_HEADS);
-			TreeMap<String, Ref> sortedRefs = new TreeMap<String, Ref>();
+			TreeMap<String, Ref> sortedRefs = new TreeMap<String, Ref>(
+					CommonUtils.STRING_ASCENDING_COMPARATOR);
 
 			// Add the MAX_NUM_MENU_ENTRIES most recently used branches first
 			List<ReflogEntry> reflogEntries = repository.getReflogReader(
@@ -172,7 +174,7 @@ public class SwitchToMenu extends ContributionItem implements
 				// nice but only if we have both recently used branches and other
 				// local branches
 				if (itemCount > 0 && localBranches.size() > 0)
-					new MenuItem(menu, SWT.SEPARATOR);
+					createSeparator(menu);
 
 				// Now add more other branches if we have only a few branch switches
 				// Sort the remaining local branches
@@ -189,7 +191,7 @@ public class SwitchToMenu extends ContributionItem implements
 				}
 			}
 			if (itemCount > 0)
-				new MenuItem(menu, SWT.SEPARATOR);
+				createSeparator(menu);
 			MenuItem others = new MenuItem(menu, SWT.PUSH);
 			others.setText(UIText.SwitchToMenu_OtherMenuLabel);
 			others.addSelectionListener(new SelectionAdapter() {
@@ -203,6 +205,10 @@ public class SwitchToMenu extends ContributionItem implements
 		}
 	}
 
+	private static MenuItem createSeparator(Menu menu) {
+		return new MenuItem(menu, SWT.SEPARATOR);
+	}
+
 	private void createMenuItem(Menu menu, final Repository repository,
 			String currentBranch, final String fullName, String shortName) {
 		final MenuItem item = new MenuItem(menu, SWT.PUSH);
