@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010 SAP AG.
+ * Copyright (c) 2010, 2013 SAP AG.
  * All rights reserved. This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License v1.0
  * which accompanies this distribution, and is available at
@@ -10,8 +10,11 @@
  *******************************************************************************/
 package org.eclipse.egit.ui.internal.commands.shared;
 
+import org.eclipse.egit.core.op.RebaseOperation;
 import org.eclipse.egit.ui.internal.UIText;
+import org.eclipse.egit.ui.internal.rebase.RebaseInteractiveHandler;
 import org.eclipse.jgit.api.RebaseCommand.Operation;
+import org.eclipse.jgit.lib.Repository;
 
 /**
  * Implements "Skip Rebase"
@@ -21,7 +24,13 @@ public class SkipRebaseCommand extends AbstractRebaseCommandHandler {
 	 * Default constructor
 	 */
 	public SkipRebaseCommand() {
-		super(Operation.SKIP, UIText.SkipRebaseCommand_JobName,
+		super(UIText.SkipRebaseCommand_JobName,
 				UIText.SkipRebaseCommand_CancelDialogMessage);
 	}
+
+	@Override
+	public RebaseOperation createRebaseOperation(Repository repository) {
+		return new RebaseOperation(repository, Operation.SKIP,
+				RebaseInteractiveHandler.INSTANCE);
+	}
 }
