@@ -38,8 +38,8 @@ import org.eclipse.egit.ui.Activator;
 import org.eclipse.egit.ui.UIPreferences;
 import org.eclipse.egit.ui.UIUtils;
 import org.eclipse.egit.ui.internal.GitLabelProvider;
-import org.eclipse.egit.ui.internal.UIIcons;
 import org.eclipse.egit.ui.internal.UIText;
+import org.eclipse.egit.ui.internal.actions.ResetMenu;
 import org.eclipse.egit.ui.internal.history.SWTCommitList.SWTLane;
 import org.eclipse.egit.ui.internal.history.command.HistoryViewCommands;
 import org.eclipse.egit.ui.internal.trace.GitTraceLocation;
@@ -577,11 +577,12 @@ class CommitGraphTable {
 					int firstColumnWidth = table.getTable().getColumn(0).getWidth();
 					int relativeX = e.x - firstColumnWidth - itemBounds.x;
 					for (int i = 0; i < commit.getRefCount(); i++) {
-						Point textSpan = renderer.getRefHSpan(commit.getRef(i));
+						Ref ref = commit.getRef(i);
+						Point textSpan = renderer.getRefHSpan(ref);
 						if ((textSpan != null)
 								&& (relativeX >= textSpan.x && relativeX <= textSpan.y)) {
 
-							String hoverText = getHoverText(commit.getRef(i));
+							String hoverText = getHoverText(ref, i, commit);
 							int width = textSpan.y - textSpan.x;
 							Rectangle rectangle = new Rectangle(
 									firstColumnWidth + itemBounds.x
@@ -598,7 +599,25 @@ class CommitGraphTable {
 			setInformation(null, null);
 		}
 
-		private String getHoverText(Ref r) {
+		private String getHoverText(Ref ref, int refIndex, SWTCommit commit) {
+			if (ref.getName().startsWith(Constants.R_TAGS)
+					&& renderer.isShownAsEllipsis(ref)) {
+				StringBuilder sb = new StringBuilder(UIText.CommitGraphTable_HoverAdditionalTags);
+				for (int i = refIndex; i < commit.getRefCount(); i++) {
+					Ref tag = commit.getRef(i);
+					String name = tag.getName();
+					if (name.startsWith(Constants.R_TAGS)) {
+						sb.append('\n');
+						sb.append(name.substring(Constants.R_TAGS.length()));
+					}
+				}
+				return sb.toString();
+			} else {
+				return getHoverTextForSingleRef(ref);
+			}
+		}
+
+		private String getHoverTextForSingleRef(Ref r) {
 			StringBuilder sb = new StringBuilder();
 			String name = r.getName();
 			sb.append(name);
@@ -827,27 +846,8 @@ class CommitGraphTable {
 						UIText.GitHistoryPage_rebaseInteractiveMenuItem));
 				popupMgr.add(new Separator());
 
-				MenuManager resetManager = new MenuManager(
-						UIText.GitHistoryPage_ResetMenuLabel, UIIcons.RESET,
-						"Reset"); //$NON-NLS-1$
-
+				MenuManager resetManager = ResetMenu.createMenu(site);
 				popupMgr.add(resetManager);
-
-				Map<String, String> parameters = new HashMap<String, String>();
-				parameters.put(HistoryViewCommands.RESET_MODE, "Soft"); //$NON-NLS-1$
-				resetManager.add(getCommandContributionItem(
-						HistoryViewCommands.RESET,
-						UIText.GitHistoryPage_ResetSoftMenuLabel, parameters));
-				parameters = new HashMap<String, String>();
-				parameters.put(HistoryViewCommands.RESET_MODE, "Mixed"); //$NON-NLS-1$
-				resetManager.add(getCommandContributionItem(
-						HistoryViewCommands.RESET,
-						UIText.GitHistoryPage_ResetMixedMenuLabel, parameters));
-				parameters = new HashMap<String, String>();
-				parameters.put(HistoryViewCommands.RESET_MODE, "Hard"); //$NON-NLS-1$
-				resetManager.add(getCommandContributionItem(
-						HistoryViewCommands.RESET,
-						UIText.GitHistoryPage_ResetHardMenuLabel, parameters));
 			} else if (selectionSize == 2) {
 				popupMgr.add(getCommandContributionItem(
 						HistoryViewCommands.COMPARE_VERSIONS,
@@ -890,6 +890,15 @@ class CommitGraphTable {
 
 			popupMgr.add(modifyManager);
 
+			if (selectionSize == 1) {
+				modifyManager.add(getCommandContributionItem(
+						HistoryViewCommands.REWORD,
+						UIText.GitHistoryPage_rewordMenuItem));
+				modifyManager.add(getCommandContributionItem(
+						HistoryViewCommands.EDIT,
+						UIText.GitHistoryPage_editMenuItem));
+			}
+
 			if (selectionSize >= 2)
 				modifyManager.add(getCommandContributionItem(
 						HistoryViewCommands.SQUASH,
