@@ -35,10 +35,10 @@ import org.eclipse.egit.ui.internal.repository.tree.RefNode;
 import org.eclipse.jface.dialogs.MessageDialog;
 import org.eclipse.jface.window.Window;
 import org.eclipse.jgit.lib.Constants;
+import org.eclipse.jgit.lib.ObjectId;
 import org.eclipse.jgit.lib.Ref;
 import org.eclipse.jgit.lib.Repository;
 import org.eclipse.jgit.lib.RepositoryState;
-import org.eclipse.jgit.revwalk.RevCommit;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.widgets.Display;
@@ -60,7 +60,7 @@ public class MergeHandler extends AbstractHistoryCommandHandler {
 	}
 
 	public Object execute(ExecutionEvent event) throws ExecutionException {
-		RevCommit commit = (RevCommit) getSelection(getPage()).getFirstElement();
+		ObjectId commitId = getSelectedCommitId(event);
 		final Repository repository = getRepository(event);
 		if (repository == null)
 			return null;
@@ -68,10 +68,11 @@ public class MergeHandler extends AbstractHistoryCommandHandler {
 		if (!canMerge(repository))
 			return null;
 
-		List<RefNode> nodes = getRefNodes(commit, repository, Constants.R_REFS);
+		List<RefNode> nodes = getRefNodes(commitId, repository,
+				Constants.R_REFS);
 		String refName;
 		if (nodes.isEmpty())
-			refName = commit.getName();
+			refName = commitId.getName();
 		else if (nodes.size() == 1)
 			refName = nodes.get(0).getObject().getName();
 		else {
