@@ -449,6 +449,10 @@ public class StagingView extends ViewPart implements IShowInSource {
 		parent.addDisposeListener(new DisposeListener() {
 
 			public void widgetDisposed(DisposeEvent e) {
+				if (userEnteredCommmitMessage())
+					saveCommitMessageComponentState();
+				else
+					deleteCommitMessageComponentState();
 				resources.dispose();
 				toolkit.dispose();
 			}
@@ -1982,9 +1986,7 @@ public class StagingView extends ViewPart implements IShowInSource {
 	private boolean isValidRepo(final Repository repository) {
 		return repository != null
 				&& !repository.isBare()
-				&& repository.getWorkTree().exists()
-				&& org.eclipse.egit.core.Activator.getDefault()
-						.getRepositoryUtil().contains(repository);
+				&& repository.getWorkTree().exists();
 	}
 
 	/**
@@ -2046,7 +2048,7 @@ public class StagingView extends ViewPart implements IShowInSource {
 		if (form.isDisposed())
 			return;
 		if (repository == null) {
-			asyncExec(new Runnable() {
+			syncExec(new Runnable() {
 				public void run() {
 					clearRepository();
 				}
@@ -2059,7 +2061,7 @@ public class StagingView extends ViewPart implements IShowInSource {
 
 		final boolean repositoryChanged = currentRepository != repository;
 
-		asyncExec(new Runnable() {
+		syncExec(new Runnable() {
 
 			public void run() {
 				if (form.isDisposed())
@@ -2185,13 +2187,19 @@ public class StagingView extends ViewPart implements IShowInSource {
 	}
 
 	void updateCommitMessageComponent(boolean repositoryChanged, boolean indexDiffAvailable) {
-		CommitHelper helper = new CommitHelper(currentRepository);
-		CommitMessageComponentState oldState = null;
-		if (repositoryChanged) {
+		if (repositoryChanged)
 			if (userEnteredCommmitMessage())
 				saveCommitMessageComponentState();
 			else
 				deleteCommitMessageComponentState();
+		if (!indexDiffAvailable)
+			return; // only try to restore the stored repo commit message if
+					// indexDiff is ready
+
+		CommitHelper helper = new CommitHelper(currentRepository);
+		CommitMessageComponentState oldState = null;
+		if (repositoryChanged
+				|| commitMessageComponent.getRepository() != currentRepository) {
 			oldState = loadCommitMessageComponentState();
 			commitMessageComponent.setRepository(currentRepository);
 			if (oldState == null)
@@ -2208,7 +2216,7 @@ public class StagingView extends ViewPart implements IShowInSource {
 				loadInitialState(helper);
 		amendPreviousCommitAction.setChecked(commitMessageComponent
 				.isAmending());
-		amendPreviousCommitAction.setEnabled(indexDiffAvailable && helper.amendAllowed());
+		amendPreviousCommitAction.setEnabled(helper.amendAllowed());
 		updateMessage();
 	}
 
@@ -2350,7 +2358,8 @@ public class StagingView extends ViewPart implements IShowInSource {
 		if (!commitMessageComponent.checkCommitInfo())
 			return;
 
-		if (!UIUtils.saveAllEditors(currentRepository))
+		if (!UIUtils.saveAllEditors(currentRepository,
+				UIText.StagingView_cancelCommitAfterSaving))
 			return;
 
 		String commitMessage = commitMessageComponent.getCommitMessage();
@@ -2412,8 +2421,8 @@ public class StagingView extends ViewPart implements IShowInSource {
 			refsChangedListener.remove();
 	}
 
-	private void asyncExec(Runnable runnable) {
-		PlatformUI.getWorkbench().getDisplay().asyncExec(runnable);
+	private void syncExec(Runnable runnable) {
+		PlatformUI.getWorkbench().getDisplay().syncExec(runnable);
 	}
 
 }
